@@ -120,10 +120,11 @@ printcall();
 	{
          	time_update();
 
-		if (trxmode == DIGIMODE && keyerport == MFJ1278_KEYER)
+		if (trxmode == DIGIMODE && (keyerport == GMFSK || keyerport == MFJ1278_KEYER)){
 			show_rtty();
-
-
+			printcall();
+		}	
+		
 		if  (i == 0 || strlen(hiscall)  == 0)
 		{
 			nodelay(stdscr, TRUE);            /* main loop waiting for input */
@@ -132,8 +133,10 @@ printcall();
 
 				time_update();
 
-				if (trxmode == DIGIMODE && keyerport == MFJ1278_KEYER)
+				if (trxmode == DIGIMODE && (keyerport == GMFSK || keyerport == MFJ1278_KEYER)){
 					show_rtty();
+					printcall();
+				}
 
 				x = onechar();
 
@@ -1256,8 +1259,11 @@ printcall();
 
 			  	time_update();
 
-				if (trxmode == DIGIMODE && keyerport == MFJ1278_KEYER)
+				if (trxmode == DIGIMODE && (keyerport == GMFSK || keyerport == MFJ1278_KEYER )) {
 					show_rtty();
+					mvprintw(12, 54, comment);
+					refresh();
+				}
 
 		}
 
@@ -1273,7 +1279,7 @@ extern int txdelay;
 extern char sc_device[];
 
 int fd;
-char playcommand[40];
+char playcommand[120];
 
 	if (strlen(audiofile) == 0)
 		return(0);
