@@ -31,6 +31,9 @@
  extern char hiscall[];
  extern char comment[];
  extern int defer_store;
+ extern char wkeyerbuffer[];
+ 
+ int k = 0;
 
   	if (use_rxvt == 0) attron(COLOR_PAIR(NORMCOLOR) | A_BOLD  );
 	else  attron(COLOR_PAIR(NORMCOLOR) );
@@ -38,10 +41,18 @@
 	mvprintw(12, 29, "            ");
 	mvprintw(12, 54, "                        ");
 	mvprintw(12, 29, "");
+
+	attron(COLOR_PAIR(COLOR_WHITE  | A_STANDOUT));
+
+	for (k = 1; k <= 5; k++) {
+		mvprintw(k, 0, "%s", "                                        ");	
+	}
+	
 	refresh();
 	hiscall[0] = '\0';
 	comment[0]='\0';
 	defer_store = 0;
+	wkeyerbuffer[0] = '\0';		// stop keyer ?? 
 	
   return(0);
  }
