@@ -45,7 +45,7 @@ char textbuffer[82];
 
 						for (l = k-8; l <= k ; l++)   {
 
-							strncpy (textbuffer, spot_ptr[spotarray[l]], 79);
+							strncpy (textbuffer, spot_ptr[spotarray[l]], 82);
 							 spotinfo[l][0]='\0';
 
 							if (strlen(textbuffer)> 40){
@@ -62,7 +62,7 @@ char textbuffer[82];
 
 						for (l = k-8; l <= k ; l++)   {
 
-							strncpy (textbuffer, spot_ptr[spotarray[l]], 79);
+							strncpy (textbuffer, spot_ptr[spotarray[l]], 82);
 							 spotinfo[l][0]='\0';
 
 							if (strlen(textbuffer)> 40){
@@ -187,14 +187,14 @@ while (1)  {
 				spotarray[si]=i;
 				si++;
 			}
-			strcpy(lastwwv, spot_ptr[i]);
+			strncpy(lastwwv, spot_ptr[i], 82);
 			i++;
 	}   else    if (strstr(spot_ptr[i], "WWV") != NULL) {
 			if ((cluster == CLUSTER) ){
 				spotarray[si]=i;
 				si++;
 			}
-			strcpy(lastwwv, spot_ptr[i]);
+			strncpy(lastwwv, spot_ptr[i], 82);
 			i++;
 	}    else   	if (strstr(spot_ptr[i], calldupe) != NULL) {
 				if ((cluster == CLUSTER) && (announcefilter <=2)){
