@@ -44,17 +44,27 @@ extern float node_frequencies[MAXNODES] ;
 extern char thisnode;
 extern int time_master;
 extern int nroflines;
+extern struct tm *time_ptr;
 
 int f, j, k;
 char inputbuffer[160] = "";
 char time_buf[40] = "";
 static int frcounter;
-
+static int daysecs = 0;
 
 				attron(COLOR_PAIR(COLOR_CYAN) | A_STANDOUT);
 				strncpy(time_buf, timestr, 8) ;
 				mvaddstr(12, 0,  band[bandinx]);
 				mvprintw(12, 17, time_buf);
+				
+				if (daysecs > 60) {	// update the date 1x per minute
+					daysecs = 0;
+					get_time();
+					strftime(time_buf, 60, "%d-%b-%y",  time_ptr);
+					mvprintw(12, 7,time_buf);		
+				} else {
+					daysecs++;
+				}
 
 				if (trx_control == 1) {
 					if (freq != 0.0) {
