@@ -28,7 +28,7 @@ int get_time(void)
 {
 extern struct tm *time_ptr;
 extern int timeoffset;
-extern int timecorr;
+extern long timecorr;
 
 time_t now;
 
