@@ -72,7 +72,7 @@ extern int exc_cont;
 extern char continent[];
 extern int keyerport;
 extern int commentfield;
-extern int dxped;
+//extern int dxped;
 
 int  i;
 int x = 0;
@@ -319,7 +319,7 @@ commentfield = 1;
 
 		if (x == '\n' || x == 9 ||  x == 11|| x == 92){
 
-			if  ( (exchange_serial ==1)){         /* align serial nr. */
+			if  ( (exchange_serial ==1 && comment[0] >= '0' && comment[0] <= '9')){         /* align serial nr. */
 			 	if (strlen(comment)  ==  1){
 			 	 	strcpy(commentbuf,  comment);
 			 	 	comment[0]  = '\0';
@@ -748,7 +748,7 @@ if (arrlss == 1) {                    // ---------------------------arrls-------
 // get check
 				hr=0;
 
-				for (ii = 0; ii < 7; ii++) {
+				for (ii = 0; ii < 6; ii++) {
 
 					hr = getlastpattern(checkpats[ii]);
 
@@ -991,7 +991,6 @@ char newpat[80] ;
 int i, x = 0;
 
 	if ((strlen(cmpattern) - strlen(checkstring)) > 0) {
-
 		for (i=0; i < (strlen(cmpattern)- strlen(checkstring)) - 1; i++) {
 
 			newpat[0]='\0';
