@@ -37,7 +37,10 @@
 #include "writeparas.h"
 #include "lancode.h"
 #include "keyer.h"
+#include "rtty.h"
 
 int getexchange(void);
 int checkexchange (int x);
 int getlastpattern (char *checkstring);
+char * getgrid (char *comment);
+
