@@ -22,6 +22,7 @@
 
 ------------------------------------------------------------------------*/
 
+#include "globalvars.h"
 #include "log_to_disk.h"
 
 int log_to_disk (void)
@@ -32,11 +33,6 @@ int log_to_disk (void)
 		extern char my_rst[];
 		extern char his_rst[];
 		extern char qsonrstr[5];
-		extern char logline0[81];
-		extern char logline1[81];
-		extern char logline2[81];
-		extern char logline3[81];
-		extern char logline4[];
 		extern char lan_logline[];
 		extern int rit;				
    		extern int trx_control;
@@ -63,7 +59,7 @@ int log_to_disk (void)
 				comment[0] = '\0';	/* reset the comment  string */
 				comment[30] = '\0';
 
-				store_qso();
+				store_qso(logline4);
 		} else {                          // qso from lan
 				
 				if ((lan_mutex == 2) && (lan_message[0] != thisnode) && (lan_active == 1)) {
@@ -80,7 +76,7 @@ int log_to_disk (void)
 					score2();
 					addcall2();
 
-					store_qso2();
+					store_qso(lan_logline);
 				}
 
 		}
