@@ -28,7 +28,7 @@
 #include "qsonr_to_str.h"
 #include "writeparas.h"
 #ifdef HAVE_LIBHAMLIB
-#include "rig.h"
+#include <hamlib/rig.h>
 #endif
 #include "gettxinfo.h"
 #include "lancode.h"
