@@ -240,6 +240,8 @@ extern int cw_bandwidth;
 extern int nobandchange;
 extern int change_rst;
 extern char rttyoutput[];
+extern int logfrequency;
+extern int ignoredupe;
 
 
 	char commands[MAX_COMMANDS][30]= {
@@ -396,8 +398,8 @@ extern char rttyoutput[];
 		"GMFSK=",
 		"RTTYMODE",					/* 150 */
 		"DIGIMODEM=",
-		"",
-		"",
+		"LOGFREQUENCY",
+		"IGNOREDUPE",
 		""
 	};
 
@@ -1204,6 +1206,14 @@ extern char rttyoutput[];
 				rttyoutput[strlen(rttyoutput)-1] = '\0';
 				break;
 			}
+			case 152 : {
+				logfrequency = 1;
+				break;
+			}
+			case 153 : {
+				ignoredupe = 1;
+				break;
+			}
 
 		}
 
