@@ -27,7 +27,9 @@
 #include "getpx.h"
 #include "pacc_pa.h"
 #include "tlf.h"
+#include "startmsg.h"
 
 
 int readcalls(void);
+int synclog(char *synclogfile);
 
