@@ -23,6 +23,8 @@
 
 #include "score.h"
 
+int calc_continent(int zone);
+
 
 /* LZ3NY - New one for COUNTRIES list in logcfg.dat */
 int multi_found(char prefix[]) {
@@ -31,8 +33,7 @@ int multi_found(char prefix[]) {
     extern char hiscall[];
     extern char call[];
     extern char mit_multiplier_list[][6];
-    extern char pxstr[];
-    
+
 	char tmpcall[15];
     int mit_fg=0;
 
@@ -55,7 +56,7 @@ int multi_found(char prefix[]) {
 }
 
 int exist_in_multi_list() {
-    extern char mit_multiplier_list[][6];
+//    extern char mit_multiplier_list[][6];
     extern char pxstr[];
     char prefix[10];
 
@@ -91,8 +92,6 @@ extern char pointstring[];
 extern int one_point;
 extern int two_point;
 extern int three_point;
-extern int two_eu_three_dx_points;
-extern int portable_x2;
 extern int band_score[9];
 extern int bandinx;
 extern int wpx;
@@ -102,27 +101,33 @@ extern int mycountrynr;
 extern int total;
 extern char continent[];
 extern char mycontinent[];
-extern char hiscall[];
+extern char comment[];
 extern int cqww;
 extern int arrl_fd;
-extern int universal;
 extern int arrldx_usa;
 extern int w_cty;
 extern int ve_cty;
 extern int trxmode;
+extern int cwpoints;
+extern int ssbpoints;
+extern int lowband_point_mult;
+extern int portable_x2;
+extern char hiscall[];
+
 
 /* LZ3NY mods */
-extern char multiplier_list;
-extern char contest;
+
 extern int multiplier_points;
 extern int my_cont_points;
 extern int my_country_points;
 extern int dx_cont_points;
 extern int multiplier_only;
-extern int mult_side;
+
 int is_mult=0;
 /* end LZ3NY mods */
 
+int zone;
+char *loc;
 
    if  (dupe == ISDUPE){
     	points = 0;
@@ -190,7 +195,14 @@ int is_mult=0;
    	}
    }                        // end wpx
 
-   if (cqww == 1){
+   if (cqww == 1)
+   {
+
+		if (countrynr == 0)
+		{
+			zone = atoi(comment);
+			calc_continent(zone); // sets continent
+		}
 
 		if ((countrynr == mycountrynr)){
    			points = 0;
@@ -225,7 +237,8 @@ int is_mult=0;
    }   /* end cqww */
 
 
-	if (arrl_fd == 1){
+	if (arrl_fd == 1)
+	{
 
 		 	if(trxmode == SSBMODE){
 				points=1;
@@ -242,30 +255,34 @@ int is_mult=0;
 
 	}                     // end arrl_fd
 
-	if (one_point == 1) {
+	if (one_point == 1)
+	{
     		points = 1;
     		total++;
     		pointstring[0]  = '1';
 
     		return(0);
-    	}
-	if (two_point == 1) {
+ 	}
+	if (two_point == 1)
+	{
     		points = 2;
     		total = total + 2;
     		pointstring[0]  = '2';
     		return(0);
 	}
-	if (three_point == 1) {
+	if (three_point == 1)
+	{
     		points = 3;
     		total= total + 3;
     		pointstring[0]  = '3';
 
     		return(0);
-    	}
+ 	}
 
 
 
-	if (arrldx_usa == 1) {
+	if (arrldx_usa == 1)
+	{
 
     		if ((countrynr == w_cty) || (countrynr == ve_cty)){
     	    		points = 0;
@@ -286,15 +303,31 @@ int is_mult=0;
 /* LZ3NY mods */
 	      is_mult=exist_in_multi_list();
 		  if (multiplier_only == 1) {
-				if (is_mult == 1 && multiplier_points != -1) points = multiplier_points;
-				else points = 0;
+				if (is_mult == 1 && multiplier_points != -1)
+                      points = multiplier_points;
+				else
+                      points = 0;
 		  }else {
-		  	if (is_mult == 1) {
-				if (multiplier_points != -1) points = multiplier_points;
+
+            if (is_mult == 1) {
+				if (multiplier_points != -1)
+                    points = multiplier_points;
+                else
+                    points = 0;
+
+                if (countrynr == mycountrynr) {
+		  		    if (my_country_points != -1)
+                        points = my_country_points;
+    				else if (my_cont_points != -1)
+                        points = my_cont_points;
 				else points = 0;
-		  	}else if (countrynr == mycountrynr) {
-		  		if (my_country_points != -1) points = my_country_points;
-				else if (my_cont_points != -1) points = my_cont_points;
+		       	}
+
+            }else if (countrynr == mycountrynr) {
+		  		if (my_country_points != -1)
+                    points = my_country_points;
+				else if (my_cont_points != -1)
+                    points = my_cont_points;
 				else points = 0;
 		  	}else if (strcmp(continent, mycontinent) == 0) {
 		  		if (my_cont_points != -1) points = my_cont_points;
@@ -303,6 +336,29 @@ int is_mult=0;
 	      	
 			else points = 0;
 		  }
+
+		  if (ssbpoints != 0 && cwpoints != 0)		//  e.g. arrl 10m contest
+		  {
+			if (trxmode == CWMODE)
+			{
+				points = cwpoints;
+			}
+			else if (trxmode == SSBMODE)
+			{
+				points = ssbpoints;
+			}
+			else points = 0;
+		  }
+		  
+		  if (lowband_point_mult != 0 && (bandinx < BANDINDEX_30)) // lowband 2x points
+		  	points *= 2;
+		  	
+		  if (portable_x2 == 1) {			// portable x2
+		  	loc = strstr(hiscall, "/P");
+		  	if (loc == hiscall + strlen(hiscall) - 2) {
+		  		points *= 2;
+		  	}
+		  }
 		  
 		  			    /* The Result of all ABOVE */
 		  total=total+points;
@@ -321,3 +377,39 @@ int is_mult=0;
 
    return(0);
  }
+
+
+ /* -----------------------------------------------------------------*/
+ int calc_continent(int zone)
+ {		// calculates continent from zone and sets continent
+
+ 	extern char continent[];
+
+	switch (zone)
+	{
+		case 1 ... 8 :
+			strncpy (continent, "NA" , 3);
+			break;
+		case 9 ... 13 :
+			strncpy (continent, "SA" , 3);
+			break;
+		case 14 ... 16 :
+			strncpy (continent, "EU" , 3);
+			break;
+		case 17 ... 26 :
+			strncpy (continent, "AS" , 3);
+			break;
+		case 27 ... 32 :
+			strncpy (continent, "AS" , 3);
+			break;
+		case 33 ... 39 :
+			strncpy (continent, "AF" , 3);
+			break;
+		case 40 :
+			strncpy (continent, "EU" , 3);
+			break;
+		default :
+			strncpy (continent, "??" , 3);
+	}
+return (0);
+}
