@@ -74,10 +74,11 @@ static char result[MAX_CALLS][82];
 	extern int block_part;
 	extern int bigpartlist;
 	extern int mixedmode;
+	extern int ignoredupe;
 	extern int qso_once;
 	extern int trxmode;
 	extern long int max_callmastercalls;
-	extern char callmasterarray[MAX_CALLMASTER][9];
+	extern char callmasterarray[MAX_CALLMASTER][14];
 	extern char qsos[MAX_QSOS][82];
 	extern char hiscall[];
 	extern char zone_export[];
@@ -91,14 +92,19 @@ static char result[MAX_CALLS][82];
 int srch_index=0;
 //char result[MAX_CALLS][82];
 int r_index=0;
+int o = 0;
 char s_inputbuffer[82] =  "";
 char s_inputbuffercpy[82] =  "";
+char printres[14];
+char * loc;
 static char zonebuffer[3] = "";
 static int z, z1;
 static int i, j, k, l; 
 static long int m;
 static int pxnr;
 static int qso_index = 0;
+static int xwin = 1;
+static int ywin = 1;
 
 char *tmpstr;
 
@@ -139,25 +145,34 @@ char callmaster_location[80];
 
 //
 
-		while (strlen(qsos[qso_index]) > 2)
+		while (strlen(qsos[qso_index]) > 4)
 		{
 
-			strncpy(s_inputbuffer, qsos[qso_index], 81);
+			if (((qsos[qso_index][3] == 'C' && trxmode == CWMODE) ||
+				(qsos[qso_index][3] == 'S' && trxmode == SSBMODE) ||
+				(qsos[qso_index][3] == 'D' && trxmode == DIGIMODE)) ||
+				mixedmode == 0)
+			{	
 
-			qso_index++;
+				strncpy(s_inputbuffer, qsos[qso_index], 81);
 
-			if (strstr(s_inputbuffer, hiscall) != 0)
-			{
-				strcpy(searchresult[srch_index],s_inputbuffer);
-				searchresult[srch_index][80]='\0';
+				if (strstr(s_inputbuffer, hiscall) != 0)
+				{
+					strcpy(searchresult[srch_index],s_inputbuffer);
+					searchresult[srch_index][80]='\0';
 
-				if (srch_index++ > MAX_CALLS-1) break;
+					if (srch_index++ > MAX_CALLS-1) break;
 
-				s_inputbuffer[0] = '\0';
+					s_inputbuffer[0] = '\0';
+				}
+				else
+					s_inputbuffer[0] = '\0';
+				
 			}
-			else
-				s_inputbuffer[0] = '\0';
+				
+			qso_index++;
 		}
+ 		
  		s_inputbuffer[0] = '\0';
  //
  
@@ -276,23 +291,26 @@ char callmaster_location[80];
 				{
 				if ((strncmp(band[bandinx],  s_inputbuffer,  3) == 0) || (qso_once == 1))
 				{
-					if (mixedmode == 0)
-					{
-						attron(COLOR_PAIR(DUPECOLOR) | A_STANDOUT);
-						dupe  = ISDUPE;
-						beep();
-					} else
-					{
-						if (((s_inputbuffer[3]=='C') &&
-							(trxmode == CWMODE)) ||
-							((s_inputbuffer[3]== 'S') && (trxmode == SSBMODE)))
+					if (ignoredupe == 0) {
+					
+						if (mixedmode == 0)
 						{
 							attron(COLOR_PAIR(DUPECOLOR) | A_STANDOUT);
 							dupe  = ISDUPE;
 							beep();
-						}
+						} else
+						{
+							if (((s_inputbuffer[3]=='C') &&
+								(trxmode == CWMODE)) ||
+								((s_inputbuffer[3]== 'S') && (trxmode == SSBMODE)))
+							{
+								attron(COLOR_PAIR(DUPECOLOR) | A_STANDOUT);
+								dupe  = ISDUPE;
+								beep();
+							}
 
-					}
+						} // end mixed
+					} // end ignore
 				}
 			}
 							if (s_inputbuffer[1] == '1')
@@ -673,57 +691,9 @@ else
 
 //  master.dta code
 
-	if(partials==1)
+	if(partials==1)		// check what we have worked first
 	{
 
-		if(bigpartlist == 0)
-		{
-
-			j=0;
-
-			if (use_rxvt == 0) attron(COLOR_PAIR(COLOR_WHITE | A_BOLD | A_STANDOUT));
-			else attron(COLOR_PAIR(COLOR_WHITE | A_STANDOUT));
-
-			mvprintw(13,0,"                                                                ");
-
-			mvprintw(13,0, " ??");
-
-			for (m =0; m < max_callmastercalls;  m++)
-			{
-
-			   	if(strlen(callmasterarray[m]) >=2)
-				{
-
-					tmpstr = strstr(callmasterarray[m],hiscall);
-
-					if (tmpstr != NULL)
-					{
-						if (use_rxvt == 0)
-							attron(COLOR_PAIR(COLOR_WHITE
-								| A_BOLD
-								|A_STANDOUT));
-
-						else
-							attron(COLOR_PAIR(COLOR_WHITE | A_STANDOUT));
-
-						mvprintw(13,j, "%s  ",callmasterarray[m]);
-
-						if(strlen(s_inputbuffercpy) == 0)
-							strcpy(s_inputbuffercpy, callmasterarray[m]);
-
-
-						j=j+7;
-
-
-				         	if(j>=60)         break;
-
-					}
-			   	 }
-
-
-			}
-		}   else
-		{
 			l = 0;
 			j = 0;
 
@@ -732,53 +702,99 @@ else
 			else
 				attron(COLOR_PAIR(COLOR_WHITE  | A_STANDOUT));
 
-			for(j = 0; j < 9; j++)
-			{
-				mvprintw(15+j, 38, "                                         ");
-				refresh();
+
+			for (k = 1; k <= 5; k++) {
+				mvprintw(k, 0, "%s", "                                        ");	
 			}
+			attron(COLOR_PAIR(COLOR_MAGENTA) | A_STANDOUT);
+			mvprintw(1,1, "??");
+			attron(COLOR_PAIR(COLOR_WHITE  | A_STANDOUT));
+			
+			refresh();
 
 			j = 0;
-
-			for (m =0; m < max_callmastercalls;  m++)
+			m = 0;
+			
+			for (m = 0; m < MAX_CALLS; m++)
 			{
+				if (strlen(hiscall) > 2 && strlen(searchresult[m])> 2) {
+					tmpstr = strstr(searchresult[m],hiscall);
+					if (tmpstr != 0) {
+						printres[0] = '\0';
+						strncat (printres, searchresult[m] + 29, 12);
+						
+						loc = strchr (printres, ' ');
+						
+						int length = (int) (loc - printres);
+						
+						strncpy (printres, printres, length);
+						
+						printres[length] = '\0';
+						
+						if (dupe == ISDUPE) {
+							attron(COLOR_PAIR(COLOR_MAGENTA) | A_STANDOUT);
+						} else {
+							attron(COLOR_PAIR(COLOR_YELLOW | A_BOLD | A_STANDOUT));					
+						}
+						mvprintw(xwin+l,ywin+j, "%s ", printres);
+						attron(COLOR_PAIR(COLOR_WHITE  | A_STANDOUT));
+						
+						refresh();
+						
+					
+						j += (strlen(printres)+1);
 
-			   	if(strlen(callmasterarray[m]) >=2)
-				{
-
-					tmpstr = strstr(callmasterarray[m],hiscall);
-
-					if (tmpstr != NULL)
-					{
-						if (use_rxvt == 0)
-							attron(COLOR_PAIR(COLOR_WHITE | A_BOLD | A_STANDOUT));
-						else
-							attron(COLOR_PAIR(COLOR_WHITE | A_STANDOUT));
-						mvprintw(15+l,38+j, "%s  ",callmasterarray[m]);
-
-						if(strlen(s_inputbuffercpy) == 0)
-							strcpy(s_inputbuffercpy, callmasterarray[m]);
-
-
-						j=j+7;
-
-						if(j>=42)
+						if(j>=30)
 						{
 							l ++;
 							j = 0;
 
 						}
-						if(l > 8)
-							break;
-
+						if(l > 4)
+							break;							
 					}
-			   	 }
-
-
+				}	
 			}
+			
+			o = m;
+			if (strcmp (hiscall, printres) != 0) {
+
+				for (m = 0; m< max_callmastercalls;  m++)		// now check callmaster database
+				{
+					
+				   	if(strlen(callmasterarray[m]) >=2)
+					{
+
+						tmpstr = strstr(callmasterarray[m],hiscall);
+
+						if (tmpstr != NULL)
+						{
+							if (use_rxvt == 0)
+								attron(COLOR_PAIR(COLOR_WHITE | A_BOLD | A_STANDOUT));
+							else
+								attron(COLOR_PAIR(COLOR_WHITE | A_STANDOUT));
+
+							mvprintw(xwin+l,ywin+j, "%s  ",callmasterarray[m]);
 
 
-		}
+							if(strlen(s_inputbuffercpy) == 0)
+								strcpy(s_inputbuffercpy, callmasterarray[m]);
+
+							j += (strlen(callmasterarray[m]))+1;
+
+							if(j>=30)
+							{
+								l ++;
+								j = 0;
+
+							}
+							if(l > 4)
+								break;
+
+						}
+			   		 }
+				}
+			}
 
 			if ((j <= 13)&& (l == 0)&& (use_part == 1)&&(block_part == 0))
 			{
@@ -823,7 +839,7 @@ else
 // --------------------------------------------load callmaster ------------------
  int load_callmaster(void) {
 
- extern char callmasterarray[MAX_CALLMASTER][9];
+ extern char callmasterarray[MAX_CALLMASTER][14];
  extern int arrlss;
 
  FILE *cfp ;
@@ -869,7 +885,7 @@ else
 								{
 							s_inputbuffer[strlen(s_inputbuffer)-1]='\0';
 
-							s_inputbuffer[9]='\0';
+							s_inputbuffer[12]='\0';
 							strcpy(callmasterarray[count], s_inputbuffer) ;
 							count++;
 						}
@@ -880,7 +896,7 @@ else
 						if(strlen(s_inputbuffer)>0)
 							s_inputbuffer[strlen(s_inputbuffer)-1]='\0';
 
-						s_inputbuffer[9]='\0';
+						s_inputbuffer[12]='\0';
 						strcpy(callmasterarray[count], s_inputbuffer) ;
 						count++;
 
