@@ -40,11 +40,7 @@ extern int pacc_pa_flg;
 extern int universal;
 extern int other_flg;
 extern int exchange_serial;
-extern int wysiwyg_once;
 extern int wysiwyg_multi;
-extern int addcallarea_once;
-extern int manise80;
-extern int bandinx;
 extern int w_cty;
 extern int ve_cty;
 extern int zl_cty;
@@ -81,7 +77,7 @@ char vkcall[] = "VK1AA";
 char zscall[] = "ZS6AA";
 char ua9call[] = "UA9AA";
 	
-	if (pfxmult == 0) wpx =  0;
+	if (pfxmult == 0 && wpx == 1) wpx =  0;
 	cqww = 0;
 	dxped = 0;
 	sprint = 0;
@@ -118,6 +114,7 @@ if  (strcmp(whichcontest, "cqww")  ==  0){
  	
 if  (strcmp(whichcontest, "dxped")  ==  0){	
 	dxped = 1;
+	recall_mult=1;
 	contest = 1;
 	showscore_flag = 1;
 	searchflg  = 1;		
@@ -140,10 +137,10 @@ if  (strcmp(whichcontest, "arrldx_usa")  ==  0){
 	}
 
 if  (strcmp(whichcontest, "arrldx_dx")  ==  0){
-	other_flg = 1;
+//	other_flg = 1;
 	three_point = 1;
 	recall_mult = 1;
-	wysiwyg_multi = 1;
+	sectn_mult = 1;
 	contest = 1;
 	showscore_flag = 1;
 	searchflg  = 1;
@@ -225,7 +222,7 @@ if  (strcmp(whichcontest, "qso")  ==  0){
 	searchflg  = 1;
 	}
 else{
-	searchflg = 1;
+	searchflg = 1;	//dxpedition
 	contest=1;
 	showscore_flag=1;
 	universal=1;
