@@ -61,10 +61,10 @@ FILE *fp;
 
 	for (len = 0; len < strlen(s); len += 80)    {
 
-		strncpy(spot_ptr[ptr], s+len, 80);
+		strncpy(spot_ptr[ptr], s+len, 82);
 		if (strlen(spot_ptr[ptr]) > 5){
  			lastmsg[0] = '\0';
-			strncat(lastmsg, spot_ptr[ptr],79);
+			strncat(lastmsg, spot_ptr[ptr],82);
 		}
 		
 		if (clusterlog == 1) {
@@ -83,12 +83,12 @@ FILE *fp;
 		}
 		ptr++;
 
-		if (ptr > 99) {
-		 	for (ptr=10; ptr <= 99; ptr++)
-				strcpy (spot_ptr[ptr-10], spot_ptr[ptr]);
-			for (ptr=99; ptr >=89; ptr--)
+		if (ptr > MAX_SPOTS - 1) {
+		 	for (ptr=10; ptr <= MAX_SPOTS - 1; ptr++)
+				strncpy (spot_ptr[ptr-10], spot_ptr[ptr], 82);
+			for (ptr=MAX_SPOTS - 1; ptr >= MAX_SPOTS - 11; ptr--)
 				spot_ptr[ptr][0]='\0';
-			ptr=90;
+			ptr = MAX_SPOTS - 10;
 		}
 	}
 
@@ -928,7 +928,7 @@ if (packetinterface == TELNET_INTERFACE) {
 		 wrefresh(sclwin);
 
 
-for (iptr=0; iptr < 100; iptr++)
+for (iptr=0; iptr <= MAX_SPOTS; iptr++)
  		spot_ptr[iptr][0]='\0';
 
 
