@@ -22,5 +22,4 @@
 #include "tlf.h"
 
 
-int store_qso(void);
-int store_qso2(void);
+int store_qso(char *loglineptr);
